@@ -15,7 +15,8 @@ def try2number(str):
 
 class XMLMacro:
     def __init__(self):
-        # custom 
+        # custom
+        self.tool_name = "xmacro"
         self.parse_uri_fn = None
         self.common_xmacro_paths = []
         # variables for xml parse
@@ -178,7 +179,7 @@ class XMLMacro:
             raise Exception("[line %d]"%(sys._getframe().f_lineno)+"process xmacro_value,"+str(e))
         self.out_doc = xml.dom.minidom.parseString(xml_str)
         # replace xmacro block (breadth-first)
-        for _ in range(5):
+        for _ in range(100):
             nodes = self.out_doc.getElementsByTagName("xmacro_block")
             if nodes.length != 0:
                 for node in list(nodes):
@@ -187,7 +188,7 @@ class XMLMacro:
                 break
         # check
         if self.out_doc.getElementsByTagName("xmacro_block").length != 0:
-            raise Exception("[line %d]"%(sys._getframe().f_lineno)+"recursion level too deep (must<=5).")
+            raise Exception("[line %d]"%(sys._getframe().f_lineno)+"recursion level too deep (must<=100).")
 
     def to_string(self):
         # auto-generated banner
@@ -197,11 +198,14 @@ class XMLMacro:
         src = "python script"
         if self.filename != "":
             src = self.filename 
+        banner_line_len = 83
+        if len(self.tool_name)+len(src)>34:
+            banner_line_len = 49+len(self.tool_name)+len(src)
         banner = [xml.dom.minidom.Comment(c) for c in
-              [" %s " % ('=' * 83),
-               " |    This document was autogenerated by xmacro from %-29s | " % src,
-               " |    EDITING THIS FILE BY HAND IS NOT RECOMMENDED  %-30s | " % "",
-               " %s " % ('=' * 83)]]
+              [" %s " % ('=' * banner_line_len),
+               " |    This document was autogenerated by %s from %s%*s | " %(self.tool_name,src,banner_line_len-48-len(self.tool_name)-len(src)," "),
+               " |    EDITING THIS FILE BY HAND IS NOT RECOMMENDED %*s | " %(banner_line_len - 52, " "),
+               " %s " % ('=' * banner_line_len)]]
         first = self.out_doc.firstChild
         for comment in banner:
             self.out_doc.insertBefore(comment, first)
